report_breakers

Function report_breakers 

pub(in runtime) async fn report_breakers(
    conn: &mut PgConnection,
    phase: CreditRegistrationPhase,
) -> CreditRegistrationResult<()>
Copies the state of the breakers that pause the phase to the database for the dashboard, which runs in another process.